==> dclib-0.3.17.tar.bz2: dclib-0.3.17/dclib/clistenmanager.h <==
/***************************************************************************
                          clistenmanager.h  -  description
                             -------------------
    begin                : Sun Feb 29 2004
    copyright            : (C) 2004-2005 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CLISTENMANAGER_H
#define CLISTENMANAGER_H

/**
  *@author Mathias Kster
  */

#include <dclib/dcos.h>
#include <dclib/core/cthread.h>
#include <dclib/core/csingleton.h>

class CListen;
class CListenManager;

#ifdef WIN32
template class DLL_EXPORT CSingleton<CListenManager>;
#endif

class  DLL_EXPORT CListenManager : public CSingleton<CListenManager>, public CObject {
public: 
	/** */
	CListenManager();
	/** */
	virtual ~CListenManager();

	/** */
	unsigned int GetListenPort( bool connectionwait = FALSE );
	/** */
	void AddConnectionWait();
	/** */
	void RemoveConnectionWait();
	/** */
	CString GetSocketErrorMsg() { return m_sSocketError; };
	
protected:

private:
	/** */
	int ManagerCallback( CObject *, CObject * );
	/** */
	int ListenCallback( CObject *, CObject * );
	/** */
	void StartListen();
	
	/** current used port */
	unsigned int m_nListenPort;
	/** */
	ulonglong m_nConnectionWait;
	/** socket error message */
	CString m_sSocketError;

	/** */
	CMutex m_Mutex;
	/** */
	CListen * m_pListen;
	/** */
	_CCallback * m_pCallback;
};

#endif

==> dclib-0.3.21.tar.bz2: dclib-0.3.21/dclib/clistenmanager.h <==
/***************************************************************************
                          clistenmanager.h  -  description
                             -------------------
    begin                : Sun Feb 29 2004
    copyright            : (C) 2004-2005 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CLISTENMANAGER_H
#define CLISTENMANAGER_H

/**
  *@author Mathias Kster
  *
  * ConnectionWait was a counter but was not used anywhere
  * and got removed.
  */

#include <dclib/dcos.h>
#include <dclib/core/cmutex.h>
#include <dclib/core/csingleton.h>
#include <dclib/core/cstring.h>
#include <dclib/core/ccallback.h>

class CListen;
class CListenManager;
class CCryptoListenManager;

#ifdef WIN32
template class DLL_EXPORT CSingleton<CListenManager>;
template class DLL_EXPORT CSingleton<CCryptoListenManager>;
template class DLL_EXPORT _CCallback1<int>;
#endif

class DLL_EXPORT CListenManagerBase {
public:
	/** */
	unsigned int GetListenPort();
	/** */
	CString GetSocketErrorMsg() { return m_sSocketError; };
	
protected:
	/** */
	CListenManagerBase();
	/** */
	virtual ~CListenManagerBase();
	/** called by CManager, no parameters */
	int ManagerCallback();
	/** called by a CListen with a socket descriptor int */
	int ListenCallback( int fd );
	/** A pure virtual function */
	virtual _CCallback1<int> * CreateListenCallback() = 0;
	
	/** */
	_CCallback0 * m_pCallback;
	/** */
	bool m_bCrypto;

private:
	/** */
	void StartListen();
	
	/** current used port */
	unsigned int m_nListenPort;
	/** socket error message */
	CString m_sSocketError;

	/** */
	CMutex m_Mutex;
	/** */
	CListen * m_pListen;
};

class DLL_EXPORT CListenManager : public CSingleton<CListenManager>, public CListenManagerBase {
public:
	/** */
	CListenManager();
	/** */
	virtual ~CListenManager();

protected:	
	/** */
	virtual _CCallback1<int> * CreateListenCallback();
};

class DLL_EXPORT CCryptoListenManager: public CSingleton<CCryptoListenManager>, public CListenManagerBase {
public:
	/** */
	CCryptoListenManager();
	/** */
	virtual ~CCryptoListenManager();

protected:
	/** */
	virtual _CCallback1<int> * CreateListenCallback();
};

#endif
